@@ -19,6 +19,13 @@ class LocalPorvider(BaseProvider):
         return Tdcal.calendar(start_date,end_date,freq)
     
     def list_instrument(self,univ,start_date,end_date):
+        """
+
+        :param univ:
+        :param start_date:
+        :param end_date:
+        :return:
+        """
         return InstSP.list_instrument(univ,start_date,end_date)
 
     def daily(self,instruments:list,fields:list,start_date:str,end_date:str):
@@ -30,7 +37,7 @@ class LocalPorvider(BaseProvider):
                     'volume', 'amount', 'adjpreclose', 'adjopen', 'adjhigh', 'adjlow',
                     'adjclose', 'adjfactor', 'avgprice', 'tradestatus'
         """
-        return CTDP.get_daily_share_data(instruments,fields,start_date,end_date)
+        return TDP.get_daily_share_data(instruments,fields,start_date,end_date)
     
     def daily_blocktrade(self,instruments:list,fields:list,start_date:str,end_date:str):
         """ 
@@ -39,7 +46,7 @@ class LocalPorvider(BaseProvider):
             output: DataFrame
             fields: block_price	block_volume block_amount block_frequency
         """
-        return STDP.get_daily_blocktrade(instruments,fields,start_date,end_date)
+        return TDP.get_daily_blocktrade(instruments,fields,start_date,end_date)
     
     def daily_derivative_indi(self,instruments:list,fields:list,start_date:str,end_date:str):
         """ 
@@ -58,7 +65,7 @@ class LocalPorvider(BaseProvider):
                     'net_incr_cash_cash_equ_lyr', 'up_down_limit_status',
                     'lowest_highest_status'
         """
-        return CTDP.get_daily_share_deridi(instruments,fields,start_date,end_date)
+        return TDP.get_daily_share_deridi(instruments,fields,start_date,end_date)
 
     def daily_dividend_rec(self,instruments:list,fields:list,start_date:str,end_date:str):
         """ 
@@ -69,7 +76,7 @@ class LocalPorvider(BaseProvider):
                     'rightsissue_price', 'conversed_ratio', 'seo_price', 'seo_ratio',
                     'consolidate_split_ratio'
         """
-        return STDP.get_daily_share_divdrec(instruments,fields,start_date,end_date)
+        return TDP.get_daily_share_divdrec(instruments,fields,start_date,end_date)
     
     def daily_l2indicator(self,instruments:list,fields:list,start_date:str,end_date:str):
         """
@@ -85,7 +92,7 @@ class LocalPorvider(BaseProvider):
                     's_li_entrustbuymoney', 's_li_entrustsellmoney',
                     's_li_entrustbuyamount', 's_li_entrustsellamount'
         """
-        return CTDP.get_daily_share_l2idi(instruments,fields,start_date,end_date)
+        return TDP.get_daily_share_l2idi(instruments,fields,start_date,end_date)
     
     def daily_margintrade(self,instruments:list,fields:list,start_date:str,end_date:str):
         """
@@ -102,7 +109,7 @@ class LocalPorvider(BaseProvider):
                     's_sb_vol_182d', 's_refin_sl_eod_vol', 's_refin_sb_eod_vol',
                     's_refin_sl_eop_vol', 's_refin_sl_eop_bal', 's_refin_repay_vol'
         """
-        return STDP.get_daily_margintrade(instruments,fields,start_date,end_date)
+        return TDP.get_daily_margintrade(instruments,fields,start_date,end_date)
 
     def daily_moneyflow(self,instruments:list,fields:list,start_date:str,end_date:str):
         """
@@ -154,7 +161,7 @@ class LocalPorvider(BaseProvider):
                     'buy_volume_med_order_act', 'sell_volume_med_order_act',
                     'buy_volume_small_order_act', 'sell_volume_small_order_act'
         """
-        return CTDP.get_daily_moneyflow(instruments,fields,start_date,end_date) 
+        return TDP.get_daily_moneyflow(instruments,fields,start_date,end_date) 
     
     def daily_tech_indicator(self,instruments:list,fields:list,start_date:str,end_date:str):
         """
@@ -166,7 +173,7 @@ class LocalPorvider(BaseProvider):
                     'tapi_16d', 'tapi_6d', 'vstd_10d', 'vmacd_ema12d', 'vmacd_ema26d',
                     'vrsi_6d', 'vroc_12d', 'sobv', 'vr_26d'
         """
-        return CTDP.get_daily_techindi(instruments,fields,start_date,end_date) 
+        return TDP.get_daily_techindi(instruments,fields,start_date,end_date) 
     
     def daily_yield(self,instruments:list,fields:list,start_date:str,end_date:str):
         """
@@ -184,9 +191,9 @@ class LocalPorvider(BaseProvider):
                     'alpha_day_2y', 'beta_100w', 'alpha_100w', 'beta_24m', 'beta_60m',
                     'alpha_24m', 'alpha_60m'
         """
-        return CTDP.get_daily_yield(instruments,fields,start_date,end_date) 
+        return TDP.get_daily_yield(instruments,fields,start_date,end_date) 
 
-    def daily_index(self, instruments:list,fields:list,start_date:str,end_date:str):
+    def daily_index(self, instruments:list, fields:list,start_date:str,end_date:str):
         """ 
             table_name: 'AIndexEODPrices'
             input:instruments:list,fields:list,start_date:str,end_date:str
@@ -194,7 +201,7 @@ class LocalPorvider(BaseProvider):
             fields: 'preclose', 'open', 'high', 'low', 'close', 'change', 'pctchange',
                     'volume', 'amount' 
         """
-        return CTDP.get_daily_index_data(instruments,fields,start_date,end_date)
+        return TDP.get_daily_index_data(instruments,fields,start_date,end_date)
     
     def daily_index_industries_eod(self,instruments:list,fields:list,start_date:str,end_date:str):
         """ 
@@ -203,7 +210,7 @@ class LocalPorvider(BaseProvider):
             output: DataFrame
             fields: preclose open high low close change pctchange volume amount
         """
-        return CTDP.get_daily_index_industries(instruments,fields,start_date,end_date)
+        return TDP.get_daily_index_industries(instruments,fields,start_date,end_date)
 
     def daily_aswsindex_eod(self,instruments:list,fields:list,start_date:str,end_date:str):
         """ 
@@ -212,8 +219,17 @@ class LocalPorvider(BaseProvider):
             output: DataFrame
             fields: preclose open high low close change pctchange volume amount
         """
-        return CTDP.get_daily_aswsindexeod(instruments,fields,start_date,end_date)
+        return TDP.get_daily_aswsindexeod(instruments,fields,start_date,end_date)
     
+    def daily_indexweight(self,instruments,**kws):
+        """
+            table_name: 'AIndexFreeWeight'
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: stockcode, weight
+        """
+        return TDP.get_daily_indexweight(instruments,**kws)
+
     def index_member(self,indexcode:str,start_date:str =None,end_date:str = None):
         """
             table_name: 'AIndexMembers'
@@ -231,14 +247,23 @@ class LocalPorvider(BaseProvider):
             fields : stockcode,indate,outdate
         """
         return IdxSP.index_member_citics(indexcode,start_date,end_date)
+
+    def index_member_alternative(self,indexcode:str,start_date:str =None,end_date:str = None):
+        """
+            table_name: 'AIndexAlternativeMembers'
+            input:indexcode:str,start_date:str =None,end_date:str = None
+            output: DataFrame
+            fields : stockcode,indate,outdate
+        """
+        return IdxSP.index_member_alternative(indexcode,start_date,end_date)
     
-    def ashare_ipodate(self,stkcode = None,fields =None):
+    def ashare_ipodate(self, stkcode = None, fields =None):
         """  
             table_name: 'AShareDescription'
             input:instruments:List(str),fields:List(str)
                   optional: stkcode = None,fields =None,by [ann_date,reports_period]
             output: DataFrame
-            fields : listdate,delistdate
+            fields : listdate, delistdate, list_boardname
         """
         return InstSP.ashare_ipodate(stkcode,fields)
 
@@ -272,6 +297,26 @@ class LocalPorvider(BaseProvider):
         """
         return InduSP.Industrycompo_citics(stockcode,level)
 
+    def Industrycompo_cs(self,stockcode = None,level = None):
+        """  
+            table_name: "AShareIndustriesClass_CS"
+            input:instruments:List(str),fields:List(str)
+                  optional: entry_date:str,remove_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : entry_date:str,remove_date        
+        """
+        return InduSP.Industrycompo_cs(stockcode,level)
+
+    def Industrycompo_gics(self,stockcode = None,level = None):
+        """  
+            table_name: "AShareIndustriesClass_GICS"
+            input:instruments:List(str),fields:List(str)
+                  optional: entry_date:str,remove_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : entry_date:str,remove_date        
+        """
+        return InduSP.Industrycompo_gics(stockcode,level)
+
     def Industrycompo_sw(self,stockcode = None,level = None):
         """ 
             table_name: 'AShareIndustriesClass_SW'
@@ -281,6 +326,16 @@ class LocalPorvider(BaseProvider):
             fields : entry_date:str,remove_date       
         """
         return InduSP.Industrycompo_sw(stockcode,level)
+    
+    def Industrycompo_wind(self,stockcode = None,level = None):
+        """ 
+            table_name: 'AShareIndustriesClass_WIND'
+            input:instruments:List(str),fields:List(str)
+                  optional: entry_date:str,remove_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : entry_date:str,remove_date       
+        """
+        return InduSP.Industrycompo_wind(stockcode,level)
 
     def repo_cashflow(self,instruments,fields = None,**kws):
         """
@@ -362,8 +417,27 @@ class LocalPorvider(BaseProvider):
         """
         return FRP.repo_ttmhis(instruments,fields,**kws)
 
-CTDP = getattr(daily,provider_config["CTDP"])()
-STDP = getattr(daily,provider_config["STDP"])()
+    def repo_holder_number(self,instruments,fields = None,**kws):
+        """
+            table_name: 'AShareHolderNumber'
+            input:instruments:List(str),fields:List(str)
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return FRP.repo_holder_number(instruments,fields,**kws)
+
+    def repo_issuedate_pre(self,instruments,fields = None,**kws):
+        """
+            table_name: 'AShareIssuingDatePredict'
+            input:instruments:List(str),fields:List(str)
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return FRP.repo_issuedate_pre(instruments,fields,**kws)
+
+TDP = getattr(daily,provider_config["TDP"])()
 IdxSP = getattr(status,provider_config["IdxSP"])()
 InstSP = getattr(status,provider_config["InstSP"])()
 InduSP = getattr(status,provider_config["InduSP"])()
